@@ -11,9 +11,10 @@ from pydantic import BaseModel, Field, field_validator, ConfigDict
 from datetime import datetime
 from zoneinfo import ZoneInfo
 from typing import Optional, ClassVar, List, Dict, Any
+from enum import StrEnum
 from letschatty.models.base_models.chatty_asset_model import CompanyAssetModel, ChattyAssetPreview
 from letschatty.models.utils.types.identifier import StrObjectId
-from .chain_of_thought_in_chat import ChainOfThoughtInChatTrigger, ChainOfThoughtInChat
+from .chain_of_thought_in_chat import ChainOfThoughtInChatTrigger
 from .chatty_ai_mode import ChattyAIMode
 import logging
 
@@ -35,6 +36,21 @@ class SimplifiedExecutionEvent(BaseModel):
         arbitrary_types_allowed=True
     )
 
+class HumanInterventionReason(StrEnum):
+    """
+    Reason for human intervention
+    """
+    SUGGESTED_MESSAGES = "suggested_messages"
+    CONTROL_TRIGGER = "control_trigger"
+    SOMETHING_WENT_WRONG = "something_went_wrong"
+
+
+class HumanIntervention(BaseModel):
+    """
+    Reason for human intervention
+    """
+    reason: HumanInterventionReason = Field(description="The reason for human intervention")
+    message: Optional[str] = Field(default=None, description="The message to display to the user if any")
 
 class ChattyAIAgentInChat(CompanyAssetModel):
     """
@@ -55,9 +71,8 @@ class ChattyAIAgentInChat(CompanyAssetModel):
 
     # State fields (from ChattyAIAgentAssignedToChat)
     mode: ChattyAIMode = Field(default=ChattyAIMode.OFF)
-    requires_human_intervention: bool = Field(default=False)
+    human_intervention: Optional[HumanIntervention] = Field(default=None, description="The reason for human intervention if any")
     is_processing: bool = Field(default=False)
-
     # Call tracking
     last_call_started_at: Optional[datetime] = Field(
         default=None,
@@ -81,11 +96,6 @@ class ChattyAIAgentInChat(CompanyAssetModel):
     assigned_at: datetime = Field(default_factory=lambda: datetime.now(ZoneInfo("UTC")))
     assigned_by: StrObjectId
 
-    # Embedded chain of thoughts (deprecates separate chain_of_thoughts_in_chats collection)
-    chain_of_thoughts: List[ChainOfThoughtInChat] = Field(
-        default_factory=list,
-        description="List of chain of thoughts for this AI agent in this chat. Embedded to avoid separate collection queries."
-    )
     events: List[SimplifiedExecutionEvent] = Field(default_factory=list, description="Simplified events for UI visibility")
 
     # Preview class
@@ -96,6 +106,11 @@ class ChattyAIAgentInChat(CompanyAssetModel):
         validate_by_alias=True
     )
 
+    @property
+    def requires_human_intervention(self) -> bool:
+        """Check if the AI agent requires human intervention"""
+        return self.human_intervention is not None
+
     @field_validator('last_call_started_at', 'trigger_timestamp', 'assigned_at', mode="after")
     @classmethod
     def ensure_utc(cls, v: Optional[datetime]) -> Optional[datetime]:
@@ -204,52 +219,13 @@ class ChattyAIAgentInChat(CompanyAssetModel):
         self.new_call(cot_id=cot_id, trigger=ChainOfThoughtInChatTrigger.RETRY_CALL)
         return cot_id_to_cancel
 
-    def escalate(self) -> None:
+    def escalate(self, reason: HumanInterventionReason, message: Optional[str] = None) -> None:
         """Mark as requiring human intervention"""
-        self.requires_human_intervention = True
+        self.human_intervention = HumanIntervention(reason=reason, message=message)
         self.updated_at = datetime.now(ZoneInfo("UTC"))
 
     def unescalate(self) -> None:
         """Remove requirement for human intervention"""
-        self.requires_human_intervention = False
+        self.human_intervention = None
         self.updated_at = datetime.now(ZoneInfo("UTC"))
 
-    # Chain of thoughts management methods
-
-    def get_chain_of_thought(self, cot_id: StrObjectId) -> Optional[ChainOfThoughtInChat]:
-        """Get a chain of thought by ID from the embedded list"""
-        for cot in self.chain_of_thoughts:
-            if cot.id == cot_id:
-                return cot
-        return None
-
-    def add_chain_of_thought(self, cot: ChainOfThoughtInChat) -> None:
-        """Add a chain of thought to the embedded list"""
-        # Verify it belongs to this chat and AI agent
-        if cot.chat_id != self.chat_id:
-            raise ValueError(f"Chain of thought chat_id {cot.chat_id} does not match AI agent chat_id {self.chat_id}")
-        if cot.chatty_ai_agent_id != self.asset_id:
-            raise ValueError(f"Chain of thought ai_agent_id {cot.chatty_ai_agent_id} does not match AI agent asset_id {self.asset_id}")
-
-        # Check if COT with same ID already exists
-        existing_cot = self.get_chain_of_thought(cot.id)
-        if existing_cot:
-            # Update existing COT
-            index = self.chain_of_thoughts.index(existing_cot)
-            self.chain_of_thoughts[index] = cot
-        else:
-            # Add new COT
-            self.chain_of_thoughts.append(cot)
-
-        self.updated_at = datetime.now(ZoneInfo("UTC"))
-
-    def get_current_chain_of_thought(self) -> Optional[ChainOfThoughtInChat]:
-        """Get the current active chain of thought (if processing)"""
-        if not self.last_call_cot_id:
-            return None
-        return self.get_chain_of_thought(self.last_call_cot_id)
-
-    def get_all_chain_of_thoughts(self) -> List[ChainOfThoughtInChat]:
-        """Get all chain of thoughts, sorted by created_at (newest first)"""
-        return sorted(self.chain_of_thoughts, key=lambda cot: cot.created_at, reverse=True)
-
