@@ -17,6 +17,24 @@ class Automation(BaseModel):
     chain_of_thought : Optional[str] = Field(default=None)
     # client_info: Optional[ClientInfo] = Field(default=None) me gustaría que levante el mail y/o otros atributos
 
+    @property
+    def has_automation(self) -> bool:
+        """
+        Check if there's an actual automation defined (tags, products, or flow).
+
+        Returns:
+            bool: True if there's at least one tag, product, or flow defined
+        """
+        return (
+            len(self.tags) > 0 or
+            len(self.products) > 0 or
+            len(self.flow) > 0 or
+            self.quality_score is not None or
+            self.chatty_ai_agent_config is not None or
+            self.area is not None or
+            self.highlight_description is not None
+        )
+
     @model_validator(mode='after')
     def check_agent_id(self):
         if self.area == Area.WITH_AGENT and not self.agent_id:
