@@ -5,6 +5,7 @@ import json
 from datetime import timedelta
 
 from letschatty.models.utils.definitions import Area
+from pydantic_core.core_schema import custom_error_schema
 logger = logging.getLogger("logger")
 
 class Context(BaseModel):
@@ -205,4 +206,16 @@ class OpenAIError(CustomException):
 
 class NewerAvailableMessageToBeProcessedByAiAgent(CustomException):
     def __init__(self, message="Duplicated incoming message call for ai agent", status_code=400, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class MissingAIAgentInChat(CustomException):
+    def __init__(self, message="Missing AI agent in chat", status_code=400, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class ChattyAIModeOff(CustomException):
+    def __init__(self, message="Chatty AI agent is in OFF mode", status_code=400, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class ChatWithActiveContinuousConversation(CustomException):
+    def __init__(self, message="Chat has active continuous conversation", status_code=400, **context_data):
         super().__init__(message, status_code=status_code, **context_data)
\ No newline at end of file
