@@ -18,6 +18,7 @@ from .ai_agent_collection import AiAgentCollection
 from .fast_answer_collection import FastAnswerCollection
 from .topic_collection import TopicCollection
 from .filter_criteria_collection import FilterCriteriaCollection
+from .ai_component_collection import AiComponentCollection
 
 __all__ = [
     'ProductCollection',
@@ -32,5 +33,6 @@ __all__ = [
     'FastAnswerCollection',
     'TopicCollection',
     'FilterCriteriaCollection',
+    'AiComponentCollection',
 ]
 
