@@ -12,8 +12,10 @@ class MessageTextOrCaptionOrPreview:
             return "🖼️ Mensaje de tipo imagen"
         elif isinstance(message_content, ChattyContentVideo):
             return "🎥 Mensaje de tipo video"
-        elif isinstance(message_content, ChattyContentAudio):
+        elif isinstance(message_content, ChattyContentAudio) and not message_content.transcription:
             return "🔊 Mensaje de tipo audio"
+        elif isinstance(message_content, ChattyContentAudio) and message_content.transcription:
+            return "🔊 Audio: " + message_content.transcription
         elif isinstance(message_content, ChattyContentDocument):
             return "📄 Mensaje de tipo documento"
         elif isinstance(message_content, ChattyContentSticker):
